@@ -13,7 +13,7 @@ use Try::Tiny;
 use Carp;
 use Encode 'encode';
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub new {
   my ($class, %opts) = @_;
@@ -85,6 +85,17 @@ sub select {
   if ($params->{count}) {
     $self->{params}{query}{count} = $params->{count};
   }
+  $self->{params}{query}{skip} = 0; # default is 0
+  if ($params->{skip}) {
+    $self->{params}{query}{skip} = $params->{skip};
+  }
+  $self->{params}{query}{top} = 50; # default is 50
+  if ($params->{top}) {
+    $self->{params}{query}{top} = $params->{top};
+  }
+  if ($params->{filter}) { # filter is optional
+    $self->{params}{query}{'$filter'} = $params->{filter};
+  }
 
   $self->{params}{url} = undef;
   try {
@@ -186,6 +197,9 @@ WebService::Azure::Search - Request Azure Search API
       searchMode    => 'any',
       searchFields  => 'FIELDNAME',
       count         => 'BOOL',
+      skip          => 0,
+      top           => 1,
+      filter        => 'OData Statement.'
     );
     $select->run; # run Select Statement. return to hash reference.
     # Run Insert request
